import os
from urllib2 import HTTPError, URLError
import click
from shellfoundry.utilities.shell_config_reader import ShellConfigReader
from shellfoundry.utilities.config_reader import Configuration, CloudShellConfigReader
from shellfoundry.utilities.installer import ShellInstaller
from shellfoundry.utilities.shell_package import ShellPackage
from shellfoundry.utilities.shell_package_installer import ShellPackageInstaller
from shellfoundry.exceptions import FatalError


class InstallCommandExecutor(object):
    def __init__(self, cloudshell_config_reader=None, installer=None, shell_config_reader=None,
                 shell_package_installer=None):
        self.cloudshell_config_reader = cloudshell_config_reader or Configuration(CloudShellConfigReader())
        self.installer = installer or ShellInstaller()
        self.shell_config_reader = shell_config_reader or ShellConfigReader()
        self.shell_package_installer = shell_package_installer or ShellPackageInstaller()

    def install(self):
        current_path = os.getcwd()
        shell_package = ShellPackage(current_path)
        if shell_package.is_tosca():
            self.shell_package_installer.install(current_path)
        else:
            self._install_old_school_shell()
        click.secho('Successfully installed shell', fg='green')

    def _install_old_school_shell(self):
        try:
            cloudshell_config = self.cloudshell_config_reader.read()
            shell_config = self.shell_config_reader.read()
            self.installer.install(shell_config.name, cloudshell_config)
        except HTTPError:
            raise FatalError(u'Login to CloudShell failed. Please verify the credentials in the config')
        except URLError:
            raise FatalError(u'Connection to CloudShell Server failed. Please make sure it is up and running properly.')
        except Exception as e:
            raise FatalError(u"Failed to install shell. CloudShell responded with: '{}'".format(e.message))
